@@ -25,9 +25,10 @@
 #ifndef META_COMMON_H
 #define META_COMMON_H
 
-/* Don't include GTK or core headers here */
+/* Don't include core headers here */
 #include <X11/Xlib.h>
 #include <glib.h>
+#include <gtk/gtk.h>
 
 typedef struct _MetaResizePopup MetaResizePopup;
 
@@ -300,13 +301,32 @@ struct _MetaButtonLayout
   gboolean right_buttons_has_spacer[MAX_BUTTONS_PER_CORNER];
 };
 
+typedef struct _MetaFrameBorders MetaFrameBorders;
+struct _MetaFrameBorders
+{
+  /* The frame border is made up of two pieces - an inner visible portion
+   * and an outer portion that is invisible but responds to events.
+   */
+  GtkBorder visible;
+  GtkBorder invisible;
+
+  /* For convenience, we have a "total" border which is equal to the sum
+   * of the two borders above. */
+  GtkBorder total;
+};
+
+/* sets all dimensions to zero */
+void meta_frame_borders_clear (MetaFrameBorders *self);
+
 /* should investigate changing these to whatever most apps use */
-#define META_ICON_WIDTH 48
-#define META_ICON_HEIGHT 48
+#define META_DEFAULT_ICON_SIZE 48
+#define META_MIN_ICON_SIZE 8
+#define META_MAX_ICON_SIZE 256
+
 #define META_MINI_ICON_WIDTH 16
 #define META_MINI_ICON_HEIGHT 16
 
-#define META_DEFAULT_ICON_NAME "window"
+#define META_DEFAULT_ICON_NAME "preferences-desktop-theme"
 
 #define META_PRIORITY_PREFS_NOTIFY   (G_PRIORITY_DEFAULT_IDLE + 10)
 #define META_PRIORITY_WORK_AREA_HINT (G_PRIORITY_DEFAULT_IDLE + 15)
@@ -327,4 +347,11 @@ typedef enum
   META_PLACEMENT_MODE_MANUAL
 } MetaPlacementMode;
 
+#define META_DEFAULT_ALT_TAB_MAX_COLUMNS 5
+#define META_MIN_ALT_TAB_MAX_COLUMNS 1
+#define META_MAX_ALT_TAB_MAX_COLUMNS 64
+
+#define META_DEFAULT_ALT_TAB_RAISE_WINDOWS FALSE
+#define META_DEFAULT_ALT_TAB_EXPAND_TO_FIT_TITLE FALSE
+
 #endif
